==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_COMMENT","athugasemd");
define("_CONFIGURE","Stillingar");
define("_LOGINCREATE","Innskrning/Skr njan notanda");
define("_THRESHOLD","rskuldur");
define("_NOCOMMENTS","Engar athugasemdir");
define("_NESTED","Inndregin listi");
define("_FLAT","Flatur listi");
define("_THREAD","Spjallrir");
define("_OLDEST","Elsta fyrst");
define("_NEWEST","Njasta fyrst");
define("_HIGHEST","Stigahstu fyrst");
define("_COMMENTSWARNING","Athugasemdirnar eru skoanir vikomandi aila en ekki vefstjra.");
define("_SCORE","Einkunn:");
define("_USERINFO","Notandaupplsingar");
define("_READREST","Lesa afganginn af athugasemdinni...");
define("_REPLY","Svara essu");
define("_REPLYMAIN","Gera athugasemd");
define("_NOSUBJECT","Engin fyrirsgn");
define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account\">skr ig hr</a>");
define("_PARENT","Efst  r");
define("_ROOT","Efst");
define("_UCOMMENT","Athugasemd");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_POSTANON","Senda nafnlaust");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ONN","um...");
define("_SUBJECT","Efni");
define("_SURVEYCOM","Athugasemd vi knnun");
define("_SURVEYCOMPRE","Forskoa athugasemd vi knnun");
define("_NOTRIGHT","Eitthva fr forgrum vi a flytja breytu  etta fall. essi skilabo eru einungis til a rugla ekki hlutum seinna meir");
define("_DIRECTCOM","Bein athugasemd vi knnun...");
define("_SENDAMSG","Senda skilabo");
define("_PASTSURVEYS","Fyrri kannanir");



define("_LVOTES","atkvi");
define("_TOTALVOTES","Fjldi atkva:");
define("_VOTING","Kjrklefinn");
define("_OTHERPOLLS","Arar kannanir");
define("_CURRENTSURVEY","Nverandi knnun");
define("_CURRENTPOLLRESULTS","Niurstur");
define("_PREVIEW","Lesa yfir");
define("_REFRESH","Endurhlaa");
define("_SURVEYS","Skoanakannanir");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_COMMENT","athugasemd");
define("_CONFIGURE","Stillingar");
define("_LOGINCREATE","Innskrning/Skr njan notanda");
define("_THRESHOLD","rskuldur");
define("_NOCOMMENTS","Engar athugasemdir");
define("_NESTED","Inndregin listi");
define("_FLAT","Flatur listi");
define("_THREAD","Spjallrir");
define("_OLDEST","Elsta fyrst");
define("_NEWEST","Njasta fyrst");
define("_HIGHEST","Stigahstu fyrst");
define("_COMMENTSWARNING","Athugasemdirnar eru skoanir vikomandi aila en ekki vefstjra.");
define("_SCORE","Einkunn:");
define("_USERINFO","Notandaupplsingar");
define("_READREST","Lesa afganginn af athugasemdinni...");
define("_REPLY","Svara essu");
define("_REPLYMAIN","Gera athugasemd");
define("_NOSUBJECT","Engin fyrirsgn");
define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account\">skr ig hr</a>");
define("_PARENT","Efst  r");
define("_ROOT","Efst");
define("_UCOMMENT","Athugasemd");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_POSTANON","Senda nafnlaust");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ONN","um...");
define("_SUBJECT","Efni");
define("_SURVEYCOM","Athugasemd vi knnun");
define("_SURVEYCOMPRE","Forskoa athugasemd vi knnun");
define("_NOTRIGHT","Eitthva fr forgrum vi a flytja breytu  etta fall. essi skilabo eru einungis til a rugla ekki hlutum seinna meir");
define("_DIRECTCOM","Bein athugasemd vi knnun...");
define("_SENDAMSG","Senda skilabo");
define("_PASTSURVEYS","Fyrri kannanir");



define("_LVOTES","atkvi");
define("_TOTALVOTES","Fjldi atkva:");
define("_VOTING","Kjrklefinn");
define("_OTHERPOLLS","Arar kannanir");
define("_CURRENTSURVEY","Nverandi knnun");
define("_CURRENTPOLLRESULTS","Niurstur");
define("_PREVIEW","Lesa yfir");
define("_REFRESH","Endurhlaa");
define("_SURVEYS","Skoanakannanir");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
